==> fred-backend-logger_1.2.0.orig.tar.gz: fred-backend-logger-1.2.0/src/handle_request.cc <==
/*
 * Copyright (C) 2020  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "src/handle_request.hh"

#include "src/cfg.hh"

#include "libpg/pg_ro_transaction.hh"
#include "libpg/pg_rw_transaction.hh"

#include <exception>
#include <netdb.h>
#include <stdint.h>

namespace Fred {
namespace Logger {

namespace {

LibPg::Dsn get_dsn()
{
    static LibPg::Dsn dsn;
    dsn.host = LibPg::Dsn::Host{Cfg::Options::get().database.host};
    if (Cfg::Options::get().database.host_addr != boost::none)
    {
            dsn.host_addr = LibPg::Dsn::HostAddr{boost::asio::ip::address::from_string(*Cfg::Options::get().database.host_addr)};
    }
    if (Cfg::Options::get().database.port != boost::none)
    {
        dsn.port = LibPg::Dsn::Port{std::uint16_t(*Cfg::Options::get().database.port)};
    }
    dsn.db_name = LibPg::Dsn::DbName{Cfg::Options::get().database.dbname};
    dsn.user = LibPg::Dsn::User{Cfg::Options::get().database.user};
    if (Cfg::Options::get().database.password != boost::none)
    {
        dsn.password = LibPg::Dsn::Password{*Cfg::Options::get().database.password};
    }
    dsn.connect_timeout = LibPg::Dsn::ConnectTimeout{std::chrono::seconds{*Cfg::Options::get().database.timeout}};
    return dsn;
}

} // namespace Fred::Logger::{anonymous}

CreateLogEntryReply handle_request(const CreateLogEntryRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    auto result =
            create_log_entry(
                    rw_transaction,
                    _request.ip,
                    _request.log_entry_service,
                    _request.log_entry_content,
                    _request.log_entry_properties,
                    _request.object_references,
                    _request.log_entry_type,
                    _request.session_ident);
    commit(std::move(rw_transaction));
    return result;
}

void handle_request(const CloseLogEntryRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    close_log_entry(
            rw_transaction,
            _request.log_entry_ident,
            _request.log_entry_content,
            _request.log_entry_properties,
            _request.object_references,
            _request.result_code_or_name,
            _request.session_ident);
    commit(std::move(rw_transaction));
}

CreateSessionReply handle_request(const CreateSessionRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    auto result =
            create_session(
                    rw_transaction,
                    _request.username,
                    _request.user_id);
    commit(std::move(rw_transaction));
    return result;
}

void handle_request(const CloseSessionRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    close_session(
            rw_transaction,
            _request.session_ident);
    commit(std::move(rw_transaction));
}

GetLogEntryTypesReply handle_request(const GetLogEntryTypesRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            get_log_entry_types(
                    ro_transaction,
                    _request.log_entry_service);
    commit(std::move(ro_transaction));
    return result;
}

GetServicesReply handle_request(const GetServicesRequest&)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            get_services(
                    ro_transaction);
    commit(std::move(ro_transaction));
    return result;
}

GetResultsReply handle_request(const GetResultsRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            get_results(
                    ro_transaction,
                    _request.log_entry_service);
    commit(std::move(ro_transaction));
    return result;
}

GetObjectReferenceTypesReply handle_request(const GetObjectReferenceTypesRequest&)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            get_object_reference_types(
                    ro_transaction);
    commit(std::move(ro_transaction));
    return result;
}

GetLogEntryInfoReply handle_request(const GetLogEntryInfoRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            get_log_entry_info(
                    ro_transaction,
                    _request.log_entry_ident);
    commit(std::move(ro_transaction));
    return result;
}

ListLogEntriesReply handle_request(const ListLogEntriesRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            list_log_entries(
                    ro_transaction,
                    _request.service,
                    _request.from,
                    _request.to,
                    _request.count_limit,
                    _request.username,
                    _request.user_id,
                    _request.object_reference,
                    _request.log_entry_types);
    commit(std::move(ro_transaction));
    return result;
}

} // namespace Fred::Logger
} // namespace Fred

==> fred-backend-logger_1.4.0.orig.tar.gz: fred-backend-logger-1.4.0/src/handle_request.cc <==
/*
 * Copyright (C) 2020  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "src/handle_request.hh"

#include "src/cfg.hh"
#include "src/is_monitoring_ip.hh"

#include "libpg/pg_ro_transaction.hh"
#include "libpg/pg_rw_transaction.hh"

#include <exception>
#include <netdb.h>
#include <stdint.h>

namespace Fred {
namespace Logger {

namespace {

LibPg::Dsn get_dsn()
{
    static LibPg::Dsn dsn;
    dsn.host = LibPg::Dsn::Host{Cfg::Options::get().database.host};
    if (Cfg::Options::get().database.host_addr != boost::none)
    {
            dsn.host_addr = LibPg::Dsn::HostAddr{boost::asio::ip::address::from_string(*Cfg::Options::get().database.host_addr)};
    }
    if (Cfg::Options::get().database.port != boost::none)
    {
        dsn.port = LibPg::Dsn::Port{std::uint16_t(*Cfg::Options::get().database.port)};
    }
    dsn.db_name = LibPg::Dsn::DbName{Cfg::Options::get().database.dbname};
    dsn.user = LibPg::Dsn::User{Cfg::Options::get().database.user};
    if (Cfg::Options::get().database.password != boost::none)
    {
        dsn.password = LibPg::Dsn::Password{*Cfg::Options::get().database.password};
    }
    dsn.connect_timeout = LibPg::Dsn::ConnectTimeout{std::chrono::seconds{*Cfg::Options::get().database.timeout}};
    return dsn;
}

} // namespace Fred::Logger::{anonymous}

LibLogger::CreateLogEntryReply handle_request(const CreateLogEntryRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};

    const auto monitoring_status =
                    _request.ip != boost::none
                            ? LibLogger::LogEntry::IsMonitoring{is_monitoring_ip(_request.ip->get())}
                            : LibLogger::LogEntry::IsMonitoring{false};
    auto result =
            LibLogger::create_log_entry(
                    rw_transaction,
                    _request.ip,
                    monitoring_status,
                    _request.log_entry_service,
                    _request.log_entry_content,
                    _request.log_entry_properties,
                    _request.object_references,
                    _request.log_entry_type,
                    _request.session_ident);
    commit(std::move(rw_transaction));
    return result;
}

void handle_request(const CloseLogEntryRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    close_log_entry(
            rw_transaction,
            _request.log_entry_ident,
            _request.log_entry_content,
            _request.log_entry_properties,
            _request.object_references,
            _request.result_code_or_name,
            _request.session_ident);
    commit(std::move(rw_transaction));
}

LibLogger::CreateSessionReply handle_request(const CreateSessionRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    auto result =
            LibLogger::create_session(
                    rw_transaction,
                    _request.username,
                    _request.user_id);
    commit(std::move(rw_transaction));
    return result;
}

void handle_request(const CloseSessionRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    close_session(
            rw_transaction,
            _request.session_ident);
    commit(std::move(rw_transaction));
}

LibLogger::GetLogEntryTypesReply handle_request(const GetLogEntryTypesRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            LibLogger::get_log_entry_types(
                    ro_transaction,
                    _request.log_entry_service);
    commit(std::move(ro_transaction));
    return result;
}

LibLogger::GetServicesReply handle_request(const GetServicesRequest&)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            LibLogger::get_services(
                    ro_transaction);
    commit(std::move(ro_transaction));
    return result;
}

LibLogger::GetResultsReply handle_request(const GetResultsRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            LibLogger::get_results(
                    ro_transaction,
                    _request.log_entry_service);
    commit(std::move(ro_transaction));
    return result;
}

LibLogger::GetObjectReferenceTypesReply handle_request(const GetObjectReferenceTypesRequest&)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            LibLogger::get_object_reference_types(
                    ro_transaction);
    commit(std::move(ro_transaction));
    return result;
}

void handle_request(const RegisterServiceRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    LibLogger::register_service(
            rw_transaction,
            _request.service_name,
            _request.service_handle);
    commit(std::move(rw_transaction));
}

void handle_request(const RegisterResultsRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    LibLogger::register_results(
            rw_transaction,
            _request.service,
            _request.results);
    commit(std::move(rw_transaction));
}

void handle_request(const RegisterLogEntryTypesRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    LibLogger::register_log_entry_types(
            rw_transaction,
            _request.service,
            _request.log_entry_types);
    commit(std::move(rw_transaction));
}

void handle_request(const RegisterObjectReferenceTypesRequest& _request)
{
    LibPg::PgRwTransaction rw_transaction{get_dsn()};
    LibLogger::register_object_reference_types(
            rw_transaction,
            _request.object_reference_types);
    commit(std::move(rw_transaction));
}

LibLogger::GetLogEntryInfoReply handle_request(const GetLogEntryInfoRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            LibLogger::get_log_entry_info(
                    ro_transaction,
                    _request.log_entry_ident);
    commit(std::move(ro_transaction));
    return result;
}

LibLogger::ListLogEntriesReply handle_request(const ListLogEntriesRequest& _request)
{
    LibPg::PgRoTransaction ro_transaction{get_dsn()};
    auto result =
            LibLogger::list_log_entries(
                    ro_transaction,
                    _request.service,
                    _request.from,
                    _request.to,
                    _request.count_limit,
                    _request.username,
                    _request.user_id,
                    _request.object_reference,
                    _request.log_entry_types);
    commit(std::move(ro_transaction));
    return result;
}

} // namespace Fred::Logger
} // namespace Fred
